@@ -36,7 +36,7 @@
 namespace  {
 
 // OneDrive upload fragments must be multiple of 320kb
-static const qint64 UploadChunkSize = 327680;
+const qint64 UploadChunkSize = 327680;
 
 void debugDumpResponse(const QByteArray &data)
 {
@@ -79,9 +79,11 @@ void debugDumpJsonResponse(const QByteArray &data)
 
 }
 
-OneDriveBackupOperationSyncAdaptor::OneDriveBackupOperationSyncAdaptor(SocialNetworkSyncAdaptor::DataType dataType, QObject *parent)
+OneDriveBackupOperationSyncAdaptor::OneDriveBackupOperationSyncAdaptor(SocialNetworkSyncAdaptor::DataType dataType,
+                                                                       QObject *parent)
     : OneDriveDataTypeSyncAdaptor(dataType, parent)
-    , m_sailfishBackup(new QDBusInterface("org.sailfishos.backup", "/sailfishbackup", "org.sailfishos.backup", QDBusConnection::sessionBus(), this))
+    , m_sailfishBackup(new QDBusInterface("org.sailfishos.backup", "/sailfishbackup", "org.sailfishos.backup",
+                                          QDBusConnection::sessionBus(), this))
     , m_remoteAppDir(QStringLiteral("drive/special/approot"))
 {
     m_sailfishBackup->connection().connect(
@@ -134,8 +136,8 @@ void OneDriveBackupOperationSyncAdaptor::beginSync(int accountId, const QString
     switch (operation()) {
     case Backup:
     {
-        QDBusReply<QString> createBackupReply =
-                m_sailfishBackup->call("createBackupForSyncProfile", m_accountSyncProfile->name());
+        QDBusReply<QString> createBackupReply = m_sailfishBackup->call("createBackupForSyncProfile",
+                                                                       m_accountSyncProfile->name());
         if (!createBackupReply.isValid() || createBackupReply.value().isEmpty()) {
             qCWarning(lcSocialPlugin) << "Call to createBackupForSyncProfile() failed:" << createBackupReply.error().name()
                               << createBackupReply.error().message();
@@ -168,7 +170,7 @@ void OneDriveBackupOperationSyncAdaptor::beginSync(int accountId, const QString
         QDir localDir;
         if (!localDir.mkpath(m_localFileInfo.absolutePath())) {
             qCWarning(lcSocialPlugin) << "Could not create local backup directory:" << m_localFileInfo.absolutePath()
-                              << "for OneDrive account:" << accountId;
+                                      << "for OneDrive account:" << accountId;
             setStatus(SocialNetworkSyncAdaptor::Error);
             return;
         }
@@ -301,7 +303,8 @@ void OneDriveBackupOperationSyncAdaptor::listOperationFinished()
 
     if (isError) {
         // Show error but don't set error status until error code is checked more thoroughly.
-        qCWarning(lcSocialPlugin) << "error occurred when performing Backup remote path request for OneDrive account" << accountId;
+        qCWarning(lcSocialPlugin) << "error occurred when performing Backup remote path request for OneDrive account"
+                                  << accountId;
         debugDumpResponse(data);
     }
 
@@ -319,11 +322,13 @@ void OneDriveBackupOperationSyncAdaptor::listOperationFinished()
         // Directory may be not found or be empty if user has deleted backups. Only emit the error
         // signal if parsing failed or there was an unexpected error code.
         if (!ok) {
-            errorMessage = QStringLiteral("Failed to parse directory listing at %1 for account %2").arg(remotePath).arg(accountId);
+            errorMessage = QStringLiteral("Failed to parse directory listing at %1 for account %2")
+                    .arg(remotePath).arg(accountId);
         } else if (httpCode != 200
                    && httpCode != 404
                    && httpCode != 410) {
-            errorMessage = QStringLiteral("Directory listing request at %1 for account %2 failed").arg(remotePath).arg(accountId);
+            errorMessage = QStringLiteral("Directory listing request at %1 for account %2 failed, http code: %3")
+                    .arg(remotePath).arg(accountId).arg(httpCode);
         }
 
         if (errorMessage.isEmpty()) {
@@ -395,7 +400,12 @@ void OneDriveBackupOperationSyncAdaptor::beginSyncOperation(int accountId, const
     }
 }
 
-void OneDriveBackupOperationSyncAdaptor::initialiseAppFolderRequest(int accountId, const QString &accessToken, const QString &localPath, const QString &remotePath, const QString &remoteFile, const QString &syncDirection)
+void OneDriveBackupOperationSyncAdaptor::initialiseAppFolderRequest(int accountId,
+                                                                    const QString &accessToken,
+                                                                    const QString &localPath,
+                                                                    const QString &remotePath,
+                                                                    const QString &remoteFile,
+                                                                    const QString &syncDirection)
 {
     // initialise the app folder and get the remote id of the drive/special/approot path.
     // e.g., let's say we have a final path like: drive/special/approot/Backups/ABCDEFG/backup.tar
@@ -467,7 +477,8 @@ void OneDriveBackupOperationSyncAdaptor::initialiseAppFolderFinishedHandler()
 
             // Read out the app folder remote ID from the response and set it as the parent ID of the first remote dir.
             m_remoteDirectories[0].parentId = parsed.value("id").toString();
-            qCDebug(lcSocialPlugin) << "Set the parentId of the first subfolder:" << m_remoteDirectories[0].dirName << "to:" << m_remoteDirectories[0].parentId;
+            qCDebug(lcSocialPlugin) << "Set the parentId of the first subfolder:" << m_remoteDirectories[0].dirName
+                                    << "to:" << m_remoteDirectories[0].parentId;
 
             // and begin creating the remote directory structure as required, prior to uploading the files.
             // We will create the first (intermediate) remote directory
@@ -481,7 +492,8 @@ void OneDriveBackupOperationSyncAdaptor::initialiseAppFolderFinishedHandler()
             // download the required data.
             requestData(accountId, accessToken, localPath, remotePath, remoteFile);
         } else {
-            qCWarning(lcSocialPlugin) << "invalid syncDirection specified to initialiseAppFolder request with OneDrive account:" << accountId << ":" << syncDirection;
+            qCWarning(lcSocialPlugin) << "invalid syncDirection specified to initialiseAppFolder request with OneDrive account:"
+                                      << accountId << ":" << syncDirection;
             setStatus(SocialNetworkSyncAdaptor::Error);
         }
     }
@@ -489,7 +501,12 @@ void OneDriveBackupOperationSyncAdaptor::initialiseAppFolderFinishedHandler()
     decrementSemaphore(accountId);
 }
 
-void OneDriveBackupOperationSyncAdaptor::getRemoteFolderMetadata(int accountId, const QString &accessToken, const QString &localPath, const QString &remotePath, const QString &parentId, const QString &remoteDirName)
+void OneDriveBackupOperationSyncAdaptor::getRemoteFolderMetadata(int accountId,
+                                                                 const QString &accessToken,
+                                                                 const QString &localPath,
+                                                                 const QString &remotePath,
+                                                                 const QString &parentId,
+                                                                 const QString &remoteDirName)
 {
     // we request the parent folder metadata
     // e.g., let's say we have a final path like: drive/special/approot/Backups/ABCDEFG/backup.tar
@@ -549,7 +566,8 @@ void OneDriveBackupOperationSyncAdaptor::getRemoteFolderMetadataFinishedHandler(
         setStatus(SocialNetworkSyncAdaptor::Error);
     } else {
         qCDebug(lcSocialPlugin) << "remote folder metadata request succeeded with OneDrive account:" << accountId;
-        qCDebug(lcSocialPlugin) << "remote folder:" << parsed.value("name").toString() << "has remote ID:" << parsed.value("id").toString();
+        qCDebug(lcSocialPlugin) << "remote folder:" << parsed.value("name").toString()
+                                << "has remote ID:" << parsed.value("id").toString();
         debugDumpJsonResponse(data);
         if (!parsed.contains("children")) {
             qCWarning(lcSocialPlugin) << "folder metadata request result had no children!";
@@ -568,13 +586,17 @@ void OneDriveBackupOperationSyncAdaptor::getRemoteFolderMetadataFinishedHandler(
             const QString childName = childObject.value("name").toString();
             const QString childId = childObject.value("id").toString();
             const bool isDir = childObject.keys().contains("folder");
-            qCDebug(lcSocialPlugin) << "Looking for:" << remoteDirName << ", checking child object:" << childName << "with id:" << childId << ", isDir?" << isDir;
+            qCDebug(lcSocialPlugin) << "Looking for:" << remoteDirName
+                                    << ", checking child object:" << childName
+                                    << "with id:" << childId << ", isDir?" << isDir;
             if (isDir && childName.compare(remoteDirName, Qt::CaseInsensitive) == 0) {
-                qCDebug(lcSocialPlugin) << "found folder:" << childName << "with remote id:" << childId << "for OneDrive account:" << accountId;
+                qCDebug(lcSocialPlugin) << "found folder:" << childName << "with remote id:" << childId
+                                        << "for OneDrive account:" << accountId;
                 foundChildFolder = true;
                 bool updatedMetadata = false;
                 for (int i = 0; i < m_remoteDirectories.size(); i++) {
-                    if (m_remoteDirectories[i].parentId == parentId && m_remoteDirectories[i].dirName.compare(remoteDirName, Qt::CaseInsensitive) == 0) {
+                    if (m_remoteDirectories[i].parentId == parentId
+                            && m_remoteDirectories[i].dirName.compare(remoteDirName, Qt::CaseInsensitive) == 0) {
                         // found the directory whose metadata we should update
                         m_remoteDirectories[i].remoteId = childId;
                         m_remoteDirectories[i].dirName = childName;
@@ -663,8 +685,8 @@ void OneDriveBackupOperationSyncAdaptor::requestData(int accountId, const QStrin
         incrementSemaphore(accountId);
         setupReplyTimeout(accountId, reply, 10 * 60 * 1000); // 10 minutes
     } else {
-        qCWarning(lcSocialPlugin) << "unable to create download request:" << remotePath << remoteFile << redirectUrl <<
-                          "for OneDrive account with id" << accountId;
+        qCWarning(lcSocialPlugin) << "unable to create download request:" << remotePath << remoteFile << redirectUrl
+                                  << "for OneDrive account with id" << accountId;
     }
 }
 
@@ -680,7 +702,8 @@ void OneDriveBackupOperationSyncAdaptor::remotePathFinishedHandler()
     reply->deleteLater();
     removeReplyTimeout(accountId, reply);
     if (isError) {
-        qCWarning(lcSocialPlugin) << "error occurred when performing Backup remote path request for OneDrive account" << accountId << ":";
+        qCWarning(lcSocialPlugin) << "error occurred when performing Backup remote path request for OneDrive account"
+                                  << accountId << ":";
         debugDumpJsonResponse(data);
         setStatus(SocialNetworkSyncAdaptor::Error);
         decrementSemaphore(accountId);
@@ -701,9 +724,12 @@ void OneDriveBackupOperationSyncAdaptor::remotePathFinishedHandler()
     Q_FOREACH (const QJsonValue &child, children) {
         const QString childName = child.toObject().value("name").toString();
         if (child.toObject().keys().contains("folder")) {
-            qCDebug(lcSocialPlugin) << "ignoring folder:" << childName << "under remote backup path:" << remotePath << "for OneDrive account:" << accountId;
+            qCDebug(lcSocialPlugin) << "ignoring folder:" << childName
+                                    << "under remote backup path:" << remotePath
+                                    << "for OneDrive account:" << accountId;
         } else {
-            qCDebug(lcSocialPlugin) << "found remote backup object:" << childName << "for OneDrive account:" << accountId;
+            qCDebug(lcSocialPlugin) << "found remote backup object:" << childName
+                                    << "for OneDrive account:" << accountId;
             requestData(accountId, accessToken, localPath, remotePath, childName);
         }
     }
@@ -725,7 +751,8 @@ void OneDriveBackupOperationSyncAdaptor::remoteFileFinishedHandler()
     reply->deleteLater();
     removeReplyTimeout(accountId, reply);
     if (isError) {
-        qCWarning(lcSocialPlugin) << "error occurred when performing Backup remote file request for OneDrive account" << accountId << ", got:";
+        qCWarning(lcSocialPlugin) << "error occurred when performing Backup remote file request for OneDrive account"
+                                  << accountId << ", got:";
         debugDumpJsonResponse(data);
         setStatus(SocialNetworkSyncAdaptor::Error);
         decrementSemaphore(accountId);
@@ -765,7 +792,9 @@ void OneDriveBackupOperationSyncAdaptor::remoteFileFinishedHandler()
     decrementSemaphore(accountId);
 }
 
-void OneDriveBackupOperationSyncAdaptor::uploadData(int accountId, const QString &accessToken, const QString &localPath, const QString &remotePath, const QString &localFile)
+void OneDriveBackupOperationSyncAdaptor::uploadData(int accountId, const QString &accessToken,
+                                                    const QString &localPath, const QString &remotePath,
+                                                    const QString &localFile)
 {
     // step one: ensure the remote path exists (and if not, create it)
     // step two: upload every single file from the local path to the remote path.
@@ -875,23 +904,30 @@ void OneDriveBackupOperationSyncAdaptor::uploadData(int accountId, const QString
         reply->setProperty("remotePath", remotePath);
         reply->setProperty("intermediatePath", intermediatePath);
         reply->setProperty("localFile", localFile);
-        connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(errorHandler(QNetworkReply::NetworkError)));
-        connect(reply, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(sslErrorsHandler(QList<QSslError>)));
+        connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
+                this, SLOT(errorHandler(QNetworkReply::NetworkError)));
+        connect(reply, SIGNAL(sslErrors(QList<QSslError>)),
+                this, SLOT(sslErrorsHandler(QList<QSslError>)));
+
         if (localFile.isEmpty()) {
-            connect(reply, &QNetworkReply::finished, this, &OneDriveBackupOperationSyncAdaptor::createRemotePathFinishedHandler);
+            connect(reply, &QNetworkReply::finished,
+                    this, &OneDriveBackupOperationSyncAdaptor::createRemotePathFinishedHandler);
         } else if (m_uploadSessionUrl.isEmpty()) {
-            connect(reply, &QNetworkReply::finished, this, &OneDriveBackupOperationSyncAdaptor::createUploadSessionFinishedHandler);
+            connect(reply, &QNetworkReply::finished,
+                    this, &OneDriveBackupOperationSyncAdaptor::createUploadSessionFinishedHandler);
         } else {
-            connect(reply, &QNetworkReply::uploadProgress, this, &OneDriveBackupOperationSyncAdaptor::uploadProgressHandler);
-            connect(reply, &QNetworkReply::finished, this, &OneDriveBackupOperationSyncAdaptor::filePartUploadFinishedHandler);
+            connect(reply, &QNetworkReply::uploadProgress,
+                    this, &OneDriveBackupOperationSyncAdaptor::uploadProgressHandler);
+            connect(reply, &QNetworkReply::finished,
+                    this, &OneDriveBackupOperationSyncAdaptor::filePartUploadFinishedHandler);
         }
 
         // we're requesting data.  Increment the semaphore so that we know we're still busy.
         incrementSemaphore(accountId);
         setupReplyTimeout(accountId, reply, 10 * 60 * 1000); // 10 minutes
     } else {
-        qCWarning(lcSocialPlugin) << "unable to create upload request:" << localPath << localFile << "->" << remotePath <<
-                          "for OneDrive account with id" << accountId;
+        qCWarning(lcSocialPlugin) << "unable to create upload request:" << localPath << localFile << "->" << remotePath
+                                  << "for OneDrive account with id" << accountId;
     }
 }
 
@@ -911,7 +947,8 @@ void OneDriveBackupOperationSyncAdaptor::createRemotePathFinishedHandler()
     if (isError) {
         if (httpCode == 409) {
             // we actually expect a conflict error if the folder already existed, which is fine.
-            qCDebug(lcSocialPlugin) << "remote path creation had conflict: already exists:" << intermediatePath << ".  Continuing.";
+            qCDebug(lcSocialPlugin) << "remote path creation had conflict: already exists:"
+                                    << intermediatePath << ".  Continuing.";
         } else {
             // this must be a real error.
             qCWarning(lcSocialPlugin) << "remote path creation failed:" << httpCode;
@@ -931,14 +968,18 @@ void OneDriveBackupOperationSyncAdaptor::createRemotePathFinishedHandler()
             createdDirectoryParentFolderId = m_remoteDirectories[i].parentId;
             createdDirectoryName = m_remoteDirectories[i].dirName;
         } else {
-            qCDebug(lcSocialPlugin) << "successfully created folder:" << createdDirectoryName << ", now performing parent request to get its remote id";
-            qCDebug(lcSocialPlugin) << "need to create another remote directory:" << m_remoteDirectories[i].dirName << "with parent:" << m_remoteDirectories[i].parentPath;
+            qCDebug(lcSocialPlugin) << "successfully created folder:" << createdDirectoryName
+                                    << ", now performing parent request to get its remote id";
+            qCDebug(lcSocialPlugin) << "need to create another remote directory:" << m_remoteDirectories[i].dirName
+                                    << "with parent:" << m_remoteDirectories[i].parentPath;
+
             // first, get the metadata for the most recently created path's parent, to get its remote ID.
             // after that's done, the next intermediate directory can be created.
             // NOTE: we do this (rather than attempting to parse the folder id from the response in this function)
             // because in the case where the remote path creation failed due to conflict, the response doesn't
             // contain the remote id.  So, better to have uniform code to handle all cases.
-            getRemoteFolderMetadata(accountId, accessToken, localPath, remotePath, createdDirectoryParentFolderId, createdDirectoryName);
+            getRemoteFolderMetadata(accountId, accessToken, localPath, remotePath,
+                                    createdDirectoryParentFolderId, createdDirectoryName);
             decrementSemaphore(accountId);
             return;
         }
@@ -1008,8 +1049,8 @@ void OneDriveBackupOperationSyncAdaptor::filePartUploadFinishedHandler()
     int nextRangeStart = 0;
 
     if (httpCode == 200 || httpCode == 201) { // OK or Created
-        qCDebug(lcSocialPlugin) << "successfully uploaded backup of file:" << localPath << localFile << "to:" << remotePath <<
-                          "for OneDrive account:" << accountId;
+        qCDebug(lcSocialPlugin) << "successfully uploaded backup of file:" << localPath << localFile
+                                << "to:" << remotePath << "for OneDrive account:" << accountId;
     } else if (httpCode == 202) {   // Accepted
         bool ok = false;
         const QJsonObject parsed = parseJsonObjectReplyData(data, &ok);
@@ -1034,9 +1075,9 @@ void OneDriveBackupOperationSyncAdaptor::filePartUploadFinishedHandler()
         }
 
     } else {
-        qCWarning(lcSocialPlugin) << "failed to backup file:" << localPath << localFile << "to:" << remotePath <<
-                          "for OneDrive account:" << accountId << ", code:" << httpCode
-                          << "response:" << data;
+        qCWarning(lcSocialPlugin) << "failed to backup file:" << localPath << localFile << "to:" << remotePath
+                                  << "for OneDrive account:" << accountId << ", code:" << httpCode
+                                  << "response:" << data;
         debugDumpJsonResponse(data);
         setStatus(SocialNetworkSyncAdaptor::Error);
     }
@@ -1060,9 +1101,9 @@ void OneDriveBackupOperationSyncAdaptor::downloadProgressHandler(qint64 bytesRec
     QString localPath = reply->property("localPath").toString();
     QString remotePath = reply->property("remotePath").toString();
     QString localFile = reply->property("localFile").toString();
-    qCDebug(lcSocialPlugin) << "Have download progress: bytesReceived:" << bytesReceived <<
-                      "of" << bytesTotal << ", for" << localPath << localFile <<
-                      "from" << remotePath << "with account:" << accountId;
+    qCDebug(lcSocialPlugin) << "Have download progress: bytesReceived:" << bytesReceived
+                            << "of" << bytesTotal << ", for" << localPath << localFile
+                            << "from" << remotePath << "with account:" << accountId;
 }
 
 void OneDriveBackupOperationSyncAdaptor::uploadProgressHandler(qint64 bytesSent, qint64 bytesTotal)
@@ -1072,9 +1113,8 @@ void OneDriveBackupOperationSyncAdaptor::uploadProgressHandler(qint64 bytesSent,
     QString localPath = reply->property("localPath").toString();
     QString remotePath = reply->property("remotePath").toString();
     QString localFile = reply->property("localFile").toString();
-    qCDebug(lcSocialPlugin) << "Have upload progress: bytesSent:" << bytesSent <<
-                      "of" << bytesTotal << ", for" << localPath << localFile <<
-                      "to" << remotePath << "with account:" << accountId;
+    qCDebug(lcSocialPlugin) << "Have upload progress: bytesSent:" << bytesSent << "of" << bytesTotal
+                            << ", for" << localPath << localFile << "to" << remotePath << "with account:" << accountId;
 }
 
 void OneDriveBackupOperationSyncAdaptor::finalize(int accountId)
